==> mbrowse_0.3.1.orig.tar.gz: mbrowse-0.3.1/src/icons.h <==
static char * snmp_table_xpm[] = {
"16 16 5 1",
"       c None",
".      c #000000",
"+      c #B7B7B7",
"@      c #CECECE",
"#      c #FFFFFF",
"                ",
"............... ",
".+++++++++++++.@",
".+++++++++++++.+",
"...............+",
".####+###+####.+",
".+++++++++++++.+",
".####+###+####.+",
".+++++++++++++.+",
".####+###+####.+",
".+++++++++++++.+",
".####+###+####.+",
".+++++++++++++.+",
"...............+",
" @++++++++++++++",
"                "};

static char * leaf_xpm[] = {
"16 16 7 1",
".	c None",
"+	c #000000",
"@	c #00B200",
"#	c #007100",
"$	c #878787",
"%	c #CECECE",
"                ",
"                ",
"   +++++        ",
"  +@@@@@++      ",
" +@@@@@@@@+     ",
"+@@@@@#@@@@++   ",
"+@@@@#@@#@@@@+  ",
"+@########@#@@++",
"+@@@@#@@#@@@@+$$",
"+@@@@@#@@@@++$$%",
" +@@@@@@@@+$$%  ",
"  +@@@@@++$$%   ",
"   +++++$$%     ",
"    $$$$$%      ",
"                ",
"                "};

static char * folder_xpm[] = {
"16 16 6 1",
".	c None",
"+	c #000000",
"@	c #EDED00",
"#	c #FFFFE7",
"$	c #AAAAAA",
"                ",
"  ++++          ",
" +@@@@+         ",
"+@@@@@@++++++++.",
"+#############+$",
"+#@@@@@@@@@@@@+$",
"+#@@@@@@@@@@@@+$",
"+#@@@@@@@@@@@@+$",
"+#@@@@@@@@@@@@+$",
"+#@@@@@@@@@@@@+$",
"+#@@@@@@@@@@@@+$",
"+#@@@@@@@@@@@@+$",
"+++++++++++++++$",
".$$$$$$$$$$$$$$$",
"                ",
"                "};

static char *trap[]={
"16 16 7 1",
". c None",
"# c #000000",
"e c #303030",
"b c #808080",
"c c #a0a0a0",
"d c #c00000",
"a c #c0c000",
"................",
"................",
"................",
"###############.",
"#aaaaabbaaaaaa#c",
"#abbbbbbaddaaaeb",
"#abaaabbaaadaaeb",
"#abaaabbaaaada#b",
"#abaaabbaaadaa#b",
"#abbbbbbaddaaa#b",
"#aaaaabbaaaaaa#b",
"###########ee##b",
".cbbbbbbbbbbbbbb",
"................",
"................",
"................"};

==> mbrowse-0.4.3.tar.gz: mbrowse-0.4.3/src/icons.h <==
static const char * snmp_table_xpm[] = {
"16 16 5 1",
"       c None",
".      c #000000",
"+      c #B7B7B7",
"@      c #CECECE",
"#      c #FFFFFF",
"                ",
"............... ",
".+++++++++++++.@",
".+++++++++++++.+",
"...............+",
".####+###+####.+",
".+++++++++++++.+",
".####+###+####.+",
".+++++++++++++.+",
".####+###+####.+",
".+++++++++++++.+",
".####+###+####.+",
".+++++++++++++.+",
"...............+",
" @++++++++++++++",
"                "};

static const char * leaf_xpm[] = {
"16 16 7 1",
".	c None",
"+	c #000000",
"@	c #00B200",
"#	c #007100",
"$	c #878787",
"%	c #CECECE",
"                ",
"                ",
"   +++++        ",
"  +@@@@@++      ",
" +@@@@@@@@+     ",
"+@@@@@#@@@@++   ",
"+@@@@#@@#@@@@+  ",
"+@########@#@@++",
"+@@@@#@@#@@@@+$$",
"+@@@@@#@@@@++$$%",
" +@@@@@@@@+$$%  ",
"  +@@@@@++$$%   ",
"   +++++$$%     ",
"    $$$$$%      ",
"                ",
"                "};

static const char * folder_xpm[] = {
"16 16 6 1",
".	c None",
"+	c #000000",
"@	c #EDED00",
"#	c #FFFFE7",
"$	c #AAAAAA",
"                ",
"  ++++          ",
" +@@@@+         ",
"+@@@@@@++++++++.",
"+#############+$",
"+#@@@@@@@@@@@@+$",
"+#@@@@@@@@@@@@+$",
"+#@@@@@@@@@@@@+$",
"+#@@@@@@@@@@@@+$",
"+#@@@@@@@@@@@@+$",
"+#@@@@@@@@@@@@+$",
"+#@@@@@@@@@@@@+$",
"+++++++++++++++$",
".$$$$$$$$$$$$$$$",
"                ",
"                "};

static const char *trap[]={
"16 16 7 1",
". c None",
"# c #000000",
"e c #303030",
"b c #808080",
"c c #a0a0a0",
"d c #c00000",
"a c #c0c000",
"................",
"................",
"................",
"###############.",
"#aaaaabbaaaaaa#c",
"#abbbbbbaddaaaeb",
"#abaaabbaaadaaeb",
"#abaaabbaaaada#b",
"#abaaabbaaadaa#b",
"#abbbbbbaddaaa#b",
"#aaaaabbaaaaaa#b",
"###########ee##b",
".cbbbbbbbbbbbbbb",
"................",
"................",
"................"};
